<?php

declare(strict_types=1);

namespace apexl\Io\modules\admin\enums\permissions;

use app\module\newtonsTrailers\Interface\PermissionInterface;

enum Admin implements PermissionInterface
{
    case CONFIGURE;
    case ADMINISTER;
}

